==> openwebbeans-1.7.6-source-release.zip: openwebbeans-1.7.6/webbeans-impl/src/test/java/org/apache/webbeans/test/concepts/alternatives/common/AlternativeOnClassOnlyBean.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.test.concepts.alternatives.common;

import javax.enterprise.inject.Alternative;
import javax.enterprise.inject.Produces;


/**
 * This one has the &#064;Alternative on the class and NOT on the producer method
 *
 * See Spec 5.1.1
 * <pre>
 * An alternative is selected for the bean archive if ...
 *   * the alternative is a producer method, field or resource, and the bean class
 *     that declares the method or field is listed ..
 * </pre>
 */
@Alternative
public class AlternativeOnClassOnlyBean
{

    @Produces
    @QualifierProducerBased
    public IProducedBean generateBean1()
    {
        return new ProducedBean("AlternativeOnClassOnlyBean", this);
    }
}

==> openwebbeans-4.0.3-source-release.zip: openwebbeans-4.0.3/webbeans-impl/src/test/java/org/apache/webbeans/test/concepts/alternatives/common/AlternativeOnClassOnlyBean.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.test.concepts.alternatives.common;

import jakarta.enterprise.inject.Alternative;
import jakarta.enterprise.inject.Produces;


/**
 * This one has the &#064;Alternative on the class and NOT on the producer method
 *
 * See Spec 5.1.1
 * <pre>
 * An alternative is selected for the bean archive if ...
 *   * the alternative is a producer method, field or resource, and the bean class
 *     that declares the method or field is listed ..
 * </pre>
 */
@Alternative
public class AlternativeOnClassOnlyBean
{

    @Produces
    @QualifierProducerBased
    public IProducedBean generateBean1()
    {
        return new ProducedBean("AlternativeOnClassOnlyBean", this);
    }
}
